@@ -1,3 +1,5 @@
+//! EdDSA verification tests
+
 use super::*;
 
 define_test_set!("EdDSA verify", "eddsa_verify_schema.json");
@@ -7,10 +9,9 @@ define_test_set_names!(
     Ed448 => "ed448"
 );
 
-#[derive(Debug, Copy, Clone, Hash, Eq, PartialEq, Deserialize)]
-pub enum TestFlag {
-    SignatureMalleability,
-}
+define_algorithm_map!("EDDSA" => EdDsa);
+
+define_test_flags!(SignatureMalleability);
 
 define_typeid!(TestKeyTypeId => "EDDSAKeyPair");
 
@@ -28,25 +29,12 @@ pub struct TestKey {
     typ: TestKeyTypeId,
 }
 
-#[derive(Debug, Clone, Hash, Eq, PartialEq, Deserialize)]
-#[serde(deny_unknown_fields)]
-pub struct TestKeyJwk {
-    #[serde(rename = "crv")]
-    pub curve: EdwardsCurve,
-    #[serde(deserialize_with = "vec_from_base64")]
-    pub d: Vec<u8>,
-    pub kid: String,
-    pub kty: String,
-    #[serde(deserialize_with = "vec_from_base64")]
-    pub x: Vec<u8>,
-}
-
 define_typeid!(TestGroupTypeId => "EddsaVerify");
 
 #[derive(Debug, Clone, Hash, Eq, PartialEq, Deserialize)]
 #[serde(deny_unknown_fields)]
 pub struct TestGroup {
-    pub jwk: Option<TestKeyJwk>,
+    pub jwk: Option<EddsaJwk>,
     pub key: TestKey,
     #[serde(deserialize_with = "vec_from_hex", rename = "keyDer")]
     pub der: Vec<u8>,
@@ -57,16 +45,4 @@ pub struct TestGroup {
     pub tests: Vec<Test>,
 }
 
-#[derive(Debug, Clone, Hash, Eq, PartialEq, Deserialize)]
-#[serde(deny_unknown_fields)]
-pub struct Test {
-    #[serde(rename = "tcId")]
-    pub tc_id: usize,
-    pub comment: String,
-    #[serde(deserialize_with = "vec_from_hex")]
-    pub msg: Vec<u8>,
-    #[serde(deserialize_with = "vec_from_hex")]
-    pub sig: Vec<u8>,
-    pub result: TestResult,
-    pub flags: Vec<TestFlag>,
-}
+define_test!(msg: Vec<u8>, sig: Vec<u8>);
