@@ -1,3 +1,5 @@
+//! HKDF tests
+
 use super::*;
 
 define_test_set!("HKDF", "hkdf_test_schema.json");
@@ -6,26 +8,23 @@ define_test_set_names!(
     HkdfSha1 => "hkdf_sha1",
     HkdfSha256 => "hkdf_sha256",
     HkdfSha384 => "hkdf_sha384",
-    HkdfSha512 => "hkdf_sha512"
+    HkdfSha512 => "hkdf_sha512",
 );
 
-#[derive(Debug, Copy, Clone, Hash, Eq, PartialEq, Deserialize)]
-pub enum TestFlag {
-    EmptySalt,
-    SizeTooLarge,
-}
+define_algorithm_map!(
+    "HKDF-SHA-1" => HkdfSha1,
+    "HKDF-SHA-256" => HkdfSha256,
+    "HKDF-SHA-384" => HkdfSha384,
+    "HKDF-SHA-512" => HkdfSha512,
+);
+
+define_test_flags!(EmptySalt, SizeTooLarge);
 
 define_typeid!(TestGroupTypeId => "HkdfTest");
 
-#[derive(Debug, Clone, Hash, Eq, PartialEq, Deserialize)]
-#[serde(deny_unknown_fields)]
-pub struct TestGroup {
-    #[serde(rename = "keySize")]
-    pub key_size: usize,
-    #[serde(rename = "type")]
-    typ: TestGroupTypeId,
-    pub tests: Vec<Test>,
-}
+define_test_group!(
+    "keySize" => key_size: usize,
+);
 
 #[derive(Debug, Clone, Hash, Eq, PartialEq, Deserialize)]
 #[serde(deny_unknown_fields)]
