@@ -1,17 +1,14 @@
+//! RSA PKCS1v1.5 signature generation tests
+
 use super::*;
 
 define_test_set!("RSA PKCS1 sign", "rsassa_pkcs1_generate_schema.json");
 
-define_test_set_names!(
-    RsaMisc => "rsa_sig_gen_misc"
-);
+define_test_set_names!(RsaMisc => "rsa_sig_gen_misc");
 
-#[derive(Debug, Copy, Clone, Hash, Eq, PartialEq, Deserialize)]
-pub enum TestFlag {
-    SmallPublicKey,
-    SmallModulus,
-    WeakHash,
-}
+define_algorithm_map!("RSASSA-PKCS1-v1_5" => RsaPkcs1v15);
+
+define_test_flags!(SmallPublicKey, SmallModulus, WeakHash);
 
 define_typeid!(TestGroupTypeId => "RsassaPkcs1Generate");
 
@@ -47,16 +44,4 @@ pub struct TestGroup {
     pub tests: Vec<Test>,
 }
 
-#[derive(Debug, Clone, Hash, Eq, PartialEq, Deserialize)]
-#[serde(deny_unknown_fields)]
-pub struct Test {
-    #[serde(rename = "tcId")]
-    pub tc_id: usize,
-    pub comment: String,
-    #[serde(deserialize_with = "vec_from_hex")]
-    pub msg: Vec<u8>,
-    #[serde(deserialize_with = "vec_from_hex")]
-    pub sig: Vec<u8>,
-    pub result: TestResult,
-    pub flags: Vec<TestFlag>,
-}
+define_test!(msg: Vec<u8>, sig: Vec<u8>);
